InitializeMultisig

Struct InitializeMultisig 

pub struct InitializeMultisig<'account, 'multisig, MultisigSigner: AsRef<AccountView>>
where 'account: 'multisig,
{ pub multisig: &'account AccountView, pub rent_sysvar: &'account AccountView, pub multisig_signers: &'multisig [MultisigSigner], pub m: u8, }
Initializes a multisignature account with N provided signers.

Multisignature accounts can used in place of any single owner/delegate accounts in any token instruction that require an owner/delegate to be present. The variant field represents the number of signers (M) required to validate this multisignature account.

The super::InitializeMultisig instruction requires no signers and MUST be included within the same Transaction as the system program’s CreateAccount instruction that creates the account being initialized. Otherwise another party can acquire ownership of the uninitialized account.

Accounts expected by this instruction:

  1. [writable] The multisignature account to initialize.
  2. [] Rent sysvar.
  3. ..+N [signer] The signer accounts, must equal to N where 1 <= N <= 11.

Fields

multisig: &'account AccountView

The multisignature account to initialize.

rent_sysvar: &'account AccountView

Rent sysvar.

multisig_signers: &'multisig [MultisigSigner]

The signer accounts.

m: u8

The number of signers (M) required to validate this multisignature account.

Implementations

Source

impl<'account, 'multisig, MultisigSigner: AsRef<AccountView>> InitializeMultisig<'account, 'multisig, MultisigSigner>
where 'account: 'multisig,

pub const DISCRIMINATOR: u8 = 2

pub const MAX_ACCOUNTS_LEN: usize

Maximum number of accounts expected by this instruction.

The required number of accounts will depend whether the source account has a single owner or a multisignature owner.

pub const DATA_LEN: usize = 2

Instruction data length:

  • discriminator (1 byte)
  • number of signers (1 byte)
pub fn new( multisig: &'account AccountView, rent_sysvar: &'account AccountView, multisig_signers: &'multisig [MultisigSigner], m: u8, ) -> Self

pub fn invoke(&self) -> ProgramResult