TransferChecked

Struct TransferChecked 

pub struct TransferChecked<'account, 'multisig, MultisigSigner: AsRef<AccountView>> {
    pub from: &'account AccountView,
    pub mint: &'account AccountView,
    pub to: &'account AccountView,
    pub authority: &'account AccountView,
    pub multisig_signers: &'multisig [MultisigSigner],
    pub amount: u64,
    pub decimals: u8,
}
Transfers tokens from one account to another either directly or via a delegate. If this account is associated with the native mint then equal amounts of SOL and Tokens will be transferred to the destination account.

This instruction differs from super::Transfer in that the token mint and decimals value is checked by the caller. This may be useful when creating transactions offline or within a hardware wallet.

Accounts expected by this instruction:

  • Single owner/delegate
  1. [writable] The source account.
  2. [] The token mint.
  3. [writable] The destination account.
  4. [signer] The source account’s owner/delegate.
  • Multisignature owner/delegate
  1. [writable] The source account.
  2. [] The token mint.
  3. [writable] The destination account.
  4. [] The source account’s multisignature owner/delegate.
  5. ..+M [signer] M signer accounts.

Fields

from: &'account AccountView

The source account.

mint: &'account AccountView

The token mint.

to: &'account AccountView

The destination account.

authority: &'account AccountView

The source account’s owner/delegate.

multisig_signers: &'multisig [MultisigSigner]

Multisignature signers.

amount: u64

The amount of tokens to transfer.

decimals: u8

Expected number of base 10 digits to the right of the decimal place.

Implementations

Source

impl<'account> TransferChecked<'account, '_, &'account AccountView>

pub const DISCRIMINATOR: u8 = 12

The instruction discriminator.

pub const MAX_ACCOUNTS_LEN: usize

Maximum number of accounts expected by this instruction.

The required number of accounts will depend whether the source account has a single owner or a multisignature owner.

pub const DATA_LEN: usize = 10

Instruction data length:

  • discriminator (1 byte)
  • amount (8 bytes)
  • decimals (1 byte)
pub fn new( from: &'account AccountView, mint: &'account AccountView, to: &'account AccountView, authority: &'account AccountView, amount: u64, decimals: u8, ) -> Self

Creates a new TransferChecked instruction with a single owner/delegate authority.

Source

impl<'account, 'multisig, MultisigSigner: AsRef<AccountView>> TransferChecked<'account, 'multisig, MultisigSigner>

pub fn with_multisig_signers( from: &'account AccountView, mint: &'account AccountView, to: &'account AccountView, authority: &'account AccountView, amount: u64, decimals: u8, multisig_signers: &'multisig [MultisigSigner], ) -> Self

Creates a new TransferChecked instruction with a multisignature owner/delegate authority and signer accounts.

pub fn invoke(&self) -> ProgramResult

pub fn invoke_signed(&self, signers: &[Signer<'_, '_>]) -> ProgramResult