pub struct InitializeAccount2<'account> {
pub account: &'account AccountView,
pub mint: &'account AccountView,
pub rent_sysvar: &'account AccountView,
pub owner: &'account Address,
}Expand description
Like super::InitializeAccount, but the owner pubkey is
passed via instruction data rather than the accounts list. This
variant may be preferable when using Cross Program Invocation from
an instruction that does not need the owner’s AccountInfo
otherwise.
Accounts expected by this instruction:
[writable]The account to initialize.[]The mint this account will be associated with.[]Rent sysvar.
Fields
account: &'account AccountViewThe account to initialize.
mint: &'account AccountViewThe mint this account will be associated with.
rent_sysvar: &'account AccountViewRent sysvar.
owner: &'account AddressThe new account’s owner/multisignature.
Implementations
Sourceimpl<'account> InitializeAccount2<'account>
impl<'account> InitializeAccount2<'account>
pub const DISCRIMINATOR: u8 = 16
Sourcepub const ACCOUNTS_LEN: usize = 3
pub const ACCOUNTS_LEN: usize = 3
Expected number of accounts.
Sourcepub const DATA_LEN: usize = 33
pub const DATA_LEN: usize = 33
Instruction data length:
- discriminator (1 byte)
- owner pubkey (32 bytes)
pub fn new( account: &'account AccountView, mint: &'account AccountView, rent_sysvar: &'account AccountView, owner: &'account Address, ) -> Self
pub fn invoke(&self) -> ProgramResult