pub struct SyncNative<'account> {
pub native_token: &'account AccountView,
pub rent_sysvar: Option<&'account AccountView>,
}Expand description
Given a wrapped / native token account (a token account containing SOL)
updates its amount field based on the account’s underlying lamports.
This is useful if a non-wrapped SOL account uses
system_instruction::transfer to move lamports to a wrapped token
account, and needs to have its token amount field updated.
Accounts expected by this instruction:
- Using runtime Rent sysvar
[writable]The native token account to sync with its underlying lamports.
- Using Rent sysvar account
[writable]The native token account to sync with its underlying lamports.[]Rent sysvar.
Fields
native_token: &'account AccountViewNative Token Account
rent_sysvar: Option<&'account AccountView>Implementations
Sourceimpl<'account> SyncNative<'account>
impl<'account> SyncNative<'account>
pub const DISCRIMINATOR: u8 = 17
Sourcepub const MAX_ACCOUNTS_LEN: usize = 2
pub const MAX_ACCOUNTS_LEN: usize = 2
Maximum number of accounts expected by this instruction.
The required number of accounts will depend whether the source account has a single owner or a multisignature owner.
pub fn new( native_token: &'account AccountView, rent_sysvar: Option<&'account AccountView>, ) -> Self
pub fn invoke(&self) -> ProgramResult